@@ -10,7 +10,7 @@ class Interpreter:
 
     def execute(self, command, connection_type, tcp_address):
         command_serializer = CommandSerializer()
-        serialized_command = command_serializer.encode(command, connection_type, tcp_address)
+        serialized_command = command_serializer.serialize(command, connection_type, tcp_address)
         if command.runtime_name == RuntimeName.python:
             from javonet.core.receiver.Receiver import Receiver
             response = Receiver().SendCommand(serialized_command, len(serialized_command))
@@ -19,13 +19,13 @@ class Interpreter:
             response = PythonTransmitter.send_command(serialized_command)
         command_deserializer = CommandDeserializer(response, len(response))
 
-        return command_deserializer.decode()
+        return command_deserializer.deserialize()
 
     def process(self, byte_array, byte_array_len):
         command_deserializer = CommandDeserializer(byte_array, byte_array_len)
-        received_command = command_deserializer.decode()
+        received_command = command_deserializer.deserialize()
         python_handler = Handler()
         command_serializer = CommandSerializer()
         response_command = python_handler.handle_command(received_command)
-        encoded_response = command_serializer.encode(response_command, 0, "0.0.0.0:0")
+        encoded_response = command_serializer.serialize(response_command, 0, "0.0.0.0:0")
         return encoded_response
