@@ -12,7 +12,7 @@ class InvokeStaticMethodHandler < AbstractCommandHandler
   def invoke_static_method(command)
     begin
       if command.payload.length < @required_parameters_count
-        raise "Static method parameters mismatch"
+        raise ArgumentError.new "Static method parameters mismatch"
       end
       if command.payload.length > @required_parameters_count
         args = command.payload[2..]
